% f = linfexact(X,Y)
% Train linear function y = f(x) = W.x+w by solving the normal equations
%
% In:
%   X: NxL matrix, N L-dim data points rowwise.
%   Y: NxD matrix, N D-dim data points rowwise.
% Out:
%   f: (struct) the linear function, with fields:
%      type='linf', W (DxL), w (Dx1).

% Copyright (c) 2016 by Miguel A. Carreira-Perpinan

function f = linfexact(X,Y)

